declare const _default: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    /**
     * Pass a string here to link the label to the checkbox input
     */
    checkboxId: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Title that appears above the main card title
     */
    subheading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Heading text for the card option. Usually you can put what you pass to optionValue in here
     */
    heading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Additional info that goes below the main heading
     */
    additionalInfo: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Option value for the underlying checkbox options. **If the optionValue is an Object, control the identifier which the component checks the selected option with the  `identifierToMatchOptionValue` prop**
     */
    optionValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * Value for the checkbox input. Bound by v-model from the parent.
     */
    modelValue: {
        type: ArrayConstructor;
        required: true;
    };
    /**
     * HTML name attribute for the radio button to group them together. This name should be the same for a group of radio buttons. ie. if you're looping over options, they will all pass the same name.
     */
    name: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Control whether the checkbox is on the left or right of the input. Default (not reverse) is to the right.
     */
    reverse: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Text for the optional label that sits on top of the input
     */
    labelText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Background color class for the input label
     */
    labelBgColorClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Label for inline answer. Determines whether it is used or not. Note if you're using this, you must pass in optionValue as an *object* and it must contain the property `inlineAnswerValue`
     */
    inlineAnswerLabel: {
        type: StringConstructor[];
        default: string;
    };
    /**
     * If this prop is true, component must be used inside AppOptionGroup`
     */
    asGroupItem: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * If `optionValue` is an object, then you can pass in an identifier to match the selected option off of. Defaults to `id`
     */
    identifierToMatchOptionValue: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Controls the size of component.
     */
    size: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for placeholder text within inline answer. Determines whether it is used or not.
     */
    placeholderText: {
        type: StringConstructor;
        default: string;
    };
}>, {}, {
    currentlyKeyboardFocused: boolean;
}, {
    inlineAnswerValue: {
        get(): any;
        set(newValue: any): void;
    };
    checked: {
        get(): unknown[];
        set(newValue: any): void;
    };
    isInlineAnswerExpanded(): boolean;
    isCondensedSize(): boolean;
    isDefaultSize(): boolean;
}, {
    isChecked(option: any): boolean;
    /**
     * `data-focus-visible-added gets added from the focus visible polyfill https://github.com/WICG/focus-visible. Since currently :focus-within is not supported with combination of :focus-visible, we have to do some manual work to check to see if the input is focused, and then bind to the class on the wrapping component we want to style
     */
    checkIfInputIsKeyboardFocused(): void;
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Pass a string here to link the label to the checkbox input
     */
    checkboxId: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Title that appears above the main card title
     */
    subheading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Heading text for the card option. Usually you can put what you pass to optionValue in here
     */
    heading: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Additional info that goes below the main heading
     */
    additionalInfo: {
        type: StringConstructor;
        required: false;
    };
    /**
     * Option value for the underlying checkbox options. **If the optionValue is an Object, control the identifier which the component checks the selected option with the  `identifierToMatchOptionValue` prop**
     */
    optionValue: {
        type: (ObjectConstructor | StringConstructor)[];
        required: true;
    };
    /**
     * Value for the checkbox input. Bound by v-model from the parent.
     */
    modelValue: {
        type: ArrayConstructor;
        required: true;
    };
    /**
     * HTML name attribute for the radio button to group them together. This name should be the same for a group of radio buttons. ie. if you're looping over options, they will all pass the same name.
     */
    name: {
        type: StringConstructor;
        required: true;
    };
    /**
     * Control whether the checkbox is on the left or right of the input. Default (not reverse) is to the right.
     */
    reverse: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Text for the optional label that sits on top of the input
     */
    labelText: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Background color class for the input label
     */
    labelBgColorClass: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Label for inline answer. Determines whether it is used or not. Note if you're using this, you must pass in optionValue as an *object* and it must contain the property `inlineAnswerValue`
     */
    inlineAnswerLabel: {
        type: StringConstructor[];
        default: string;
    };
    /**
     * If this prop is true, component must be used inside AppOptionGroup`
     */
    asGroupItem: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * If `optionValue` is an object, then you can pass in an identifier to match the selected option off of. Defaults to `id`
     */
    identifierToMatchOptionValue: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Controls the size of component.
     */
    size: {
        type: StringConstructor;
        required: false;
        default: string;
        validator: (prop: unknown) => boolean;
    };
    /**
     * Label for placeholder text within inline answer. Determines whether it is used or not.
     */
    placeholderText: {
        type: StringConstructor;
        default: string;
    };
}>> & Readonly<{}>, {
    size: string;
    reverse: boolean;
    labelText: string;
    labelBgColorClass: string;
    inlineAnswerLabel: string;
    asGroupItem: boolean;
    identifierToMatchOptionValue: string;
    placeholderText: string;
}, {}, {
    CheckmarkIcon: any;
    AppLabel: any;
    AppInputMultiLine: any;
    AdditionalInfo: any;
}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
